The data contains anonymized survival information for boreal caribou populations 'A' and 'C', aggregated to annual resolution with staggered year ranges. Designed to test the combination of multi-population analysis with aggregate annual data. Filter to single population for simple annual-only testing. This dataset follows the methodology described in DeCesare et al. (2012) for estimating population growth rates using adult female survival data.
Format
A tibble with columns:
- PopulationName
Name of the population
- Year
The year the observation occurred
- Month
The month the observation occurred
- StartTotal
The total number of collared caribou at the start of the month
- MortalitiesCertain
The number of confirmed caribou mortalities in the month
- MortalitiesUncertain
The total number of mortalities that were not confirmed in that month
Details
The data is released under the Open Government Licence - Alberta